@@ -35,24 +35,43 @@ class _Field(Generic[T]):
         return cast(Optional[T], value)
 
     def __set__(self, obj: Any, value: Optional[T]) -> None:
-        self.__ensure_type(value)
+        self._ensure_type(value)
+        if value is not NotSet:
+            # We need to typecast the value to field's _typ because for number types the value will be returned
+            # as float by Google Sheet's API.
+            value = self._typ(value)  # type: ignore [call-arg]
+
         return setattr(obj._data, self._field_name, value)
 
-    def __ensure_type(self, value: Any) -> None:
+    def _ensure_type(self, value: Any) -> None:
         if value is None or value is NotSet:
             return
 
-        if not isinstance(value, self._typ):
+        if isinstance(value, self._typ):
+            return
+
+        raise TypeError(f"value of field {self._field_name} has the wrong type")
+
+
+class _NumberField(_Field[T]):
+    def _ensure_type(self, value: Any) -> None:
+        if value is None or value is NotSet:
+            return
+
+        if not isinstance(value, (int, float)):
             raise TypeError(f"value of field {self._field_name} has the wrong type")
 
+        if isinstance(value, int) and not _is_ieee754_safe_integer(value):
+            raise ValueError("f{value} can't be exactly stored as number. Use string instead to avoid precision loss.")
 
-class IntegerField(_Field[int]):
+
+class IntegerField(_NumberField[int]):
     """A field for integer number values."""
 
     _typ = int
 
 
-class FloatField(_Field[float]):
+class FloatField(_NumberField[float]):
     """A field for storing floating point number values."""
 
     _typ = float
@@ -136,5 +155,9 @@ class Model(metaclass=_Meta):
             setattr(self, field, getattr(self, field))
 
 
+def _is_ieee754_safe_integer(value: int) -> bool:
+    return value == int(float(value))
+
+
 __pydoc__ = {}
 __pydoc__["StringField"] = StringField.__doc__
